"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HmyMethods = void 0;
const tslib_1 = require("tslib");
const crypto_1 = require("@harmony-js/crypto");
const helpers_1 = require("./helpers");
const ETHRegistrarController_1 = require("../out/ETHRegistrarController");
const ReverseRegistrar_1 = require("../out/ReverseRegistrar");
const ensjs_1 = tslib_1.__importDefault(require("@ensdomains/ensjs"));
const web3_1 = tslib_1.__importDefault(require("web3"));
class HmyMethods {
    constructor(params) {
        this.options = { gasPrice: 1000000000, gasLimit: 6721900 };
        this.useOneWallet = false;
        this.useMathWallet = false;
        this.init = async () => {
            const controllerAddress = await this.ens
                .name("controller.one")
                .getAddress();
            console.log("controllerAddress: ", controllerAddress);
            this.registrarController = this.hmy.contracts.createContract(ETHRegistrarController_1.ETHRegistrarController.abi, controllerAddress);
            const reverseAddress = await this.ens.name("addr.reverse").getOwner();
            console.log("reverseAddress: ", reverseAddress);
            this.reverseRegistrar = this.hmy.contracts.createContract(ReverseRegistrar_1.ReverseRegistrar.abi, reverseAddress);
            this.resolverAddress = await this.ens.name("resolver.one").getAddress();
            console.log("resolverAddress: ", this.resolverAddress);
        };
        this.setUseMetamask = (value) => value;
        this.setUseOneWallet = (value) => {
            if (!window || !window.onewallet) {
                throw new Error("OneWallet extension is not found");
            }
            this.useOneWallet = value;
        };
        this.setUseMathWallet = (value) => {
            if (!window || !window.harmony) {
                throw new Error("Math Wallet extension is not found");
            }
            this.useMathWallet = value;
        };
        this.makeCommitment = async (domain, owner, duration, secret = "", address) => {
            const ownerAddrHex = crypto_1.getAddress(owner).checksum;
            let addressHex = address ? crypto_1.getAddress(address).checksum : null;
            if (this.useOneWallet && !address) {
                let { address } = await window.onewallet.getAccount();
                addressHex = crypto_1.getAddress(address).checksum;
            }
            return await this.registrarController.methods
                .makeCommitmentWithConfig(domain, ownerAddrHex, secret, this.resolverAddress, addressHex)
                .call(this.options);
        };
        this.rentPrice = async (domain, duration) => {
            return await this.registrarController.methods
                .rentPrice(domain, duration)
                .call(this.options);
        };
        this.commit = async (commitment, sendTxCallback) => {
            return new Promise(async (resolve, reject) => {
                try {
                    if (this.useOneWallet) {
                        await helpers_1.connectToBrowserWallet(window.onewallet, this.hmy, this.registrarController.wallet, null, reject);
                    }
                    const res = await this.registrarController.methods
                        .commit(commitment)
                        .send(this.options)
                        .on("transactionHash", sendTxCallback ? sendTxCallback : () => { });
                    resolve(res);
                }
                catch (e) {
                    reject(e);
                }
            });
        };
        this.register = async (domain, owner, duration, secret = "", address, sendTxCallback) => {
            return new Promise(async (resolve, reject) => {
                try {
                    if (this.useOneWallet) {
                        await helpers_1.connectToBrowserWallet(window.onewallet, this.hmy, this.registrarController.wallet, null, reject);
                    }
                    const ownerAddrHex = crypto_1.getAddress(owner).checksum;
                    const rentPrice = await this.rentPrice(domain, duration);
                    const res = await this.registrarController.methods
                        .registerWithConfig(domain, ownerAddrHex, duration, secret, this.resolverAddress, address)
                        .send(Object.assign(Object.assign({}, this.options), { value: rentPrice }))
                        .on("transactionHash", sendTxCallback ? sendTxCallback : () => { });
                    resolve(res);
                }
                catch (e) {
                    reject(e);
                }
            });
        };
        this.hmy = params.hmy;
        this.ensAddress = params.ensAddress;
        this.nodeURL = params.nodeURL;
        const provider = new web3_1.default.providers.HttpProvider(this.nodeURL);
        this.ens = new ensjs_1.default({ provider, ensAddress: this.ensAddress });
        if (params.options) {
            this.options = params.options;
        }
    }
}
exports.HmyMethods = HmyMethods;
