"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HmyMethodsWeb3 = void 0;
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const crypto_1 = require("@harmony-js/crypto");
const ensjs_1 = tslib_1.__importDefault(require("@ensdomains/ensjs"));
const ETHRegistrarController_1 = require("../out/ETHRegistrarController");
const ReverseRegistrar_1 = require("../out/ReverseRegistrar");
const BN = require("bn.js");
class HmyMethodsWeb3 {
    constructor(params) {
        this.useMetamask = false;
        this.init = async () => {
            const controllerAddress = await this.ens
                .name("controller.one")
                .getAddress();
            console.log("controllerAddress: ", controllerAddress);
            this.registrarController = new this.web3.eth.Contract(ETHRegistrarController_1.ETHRegistrarController.abi, controllerAddress);
            const reverseAddress = await this.ens.name("addr.reverse").getOwner();
            console.log("reverseAddress: ", reverseAddress);
            this.reverseRegistrar = new this.web3.eth.Contract(ReverseRegistrar_1.ReverseRegistrar.abi, reverseAddress);
            this.resolverAddress = await this.ens.name("resolver.one").getAddress();
            console.log("resolverAddress: ", this.resolverAddress);
        };
        this.setUseOneWallet = (value) => value;
        this.setUseMathWallet = (value) => value;
        this.setUseMetamask = (value) => (this.useMetamask = value);
        this.makeCommitment = async (domain, owner, duration, secret = "", address, sendTxCallback) => {
            let accounts;
            if (this.useMetamask) {
                accounts = await ethereum.enable();
            }
            const ownerAddrHex = crypto_1.getAddress(owner).checksum;
            const account = this.useMetamask
                ? accounts[0]
                : this.web3.eth.defaultAccount;
            return await this.registrarController.methods
                .makeCommitmentWithConfig(domain, ownerAddrHex, secret, this.resolverAddress, address || account)
                .call();
        };
        this.register = async (domain, owner, duration, secret = "", address, sendTxCallback) => {
            let accounts;
            if (this.useMetamask) {
                accounts = await ethereum.enable();
            }
            const ownerAddrHex = crypto_1.getAddress(owner).checksum;
            const account = this.useMetamask
                ? accounts[0]
                : this.web3.eth.defaultAccount;
            const rentPrice = await this.rentPrice(domain, duration);
            const transaction = await this.registrarController.methods
                .registerWithConfig(domain, ownerAddrHex, duration, secret, this.resolverAddress, address || account)
                .send({
                from: account,
                gasLimit: 6721900,
                gasPrice: new BN(await this.web3.eth.getGasPrice()).mul(new BN(1)),
                value: rentPrice,
            })
                .on("transactionHash", sendTxCallback ? sendTxCallback : () => { });
            return transaction;
        };
        this.commit = async (commitment, sendTxCallback) => {
            let accounts;
            if (this.useMetamask) {
                accounts = await ethereum.enable();
            }
            const account = this.useMetamask
                ? accounts[0]
                : this.web3.eth.defaultAccount;
            return await this.registrarController.methods
                .commit(commitment)
                .send({
                from: account,
                gasLimit: 6721900,
                gasPrice: new BN(await this.web3.eth.getGasPrice()).mul(new BN(1)),
            })
                .on("transactionHash", sendTxCallback ? sendTxCallback : () => { });
        };
        this.rentPrice = async (domain, duration) => {
            return await this.registrarController.methods
                .rentPrice(domain, duration)
                .call();
        };
        this.web3 = params.web3;
        this.ensAddress = params.ensAddress;
        this.nodeURL = params.nodeURL;
        const provider = new web3_1.default.providers.HttpProvider(this.nodeURL);
        this.ens = new ensjs_1.default({ provider, ensAddress: this.ensAddress });
    }
}
exports.HmyMethodsWeb3 = HmyMethodsWeb3;
