"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHmyClient = void 0;
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const HmyMethods_1 = require("./HmyMethods");
const HmyMethodsWeb3_1 = require("./HmyMethodsWeb3");
const { Harmony } = require("@harmony-js/core");
const { ChainType } = require("@harmony-js/utils");
exports.getHmyClient = async (params) => {
    const hmy = new Harmony(params.nodeURL, {
        chainType: ChainType.Harmony,
        chainId: Number(params.chainId),
    });
    let userAddress;
    let methods;
    let nodeURL = params.nodeURL;
    if (typeof window === "object" && window.web3) {
        nodeURL = window.web3.currentProvider;
    }
    const web3 = new web3_1.default(nodeURL);
    if (params.sdk === "web3") {
        methods = new HmyMethodsWeb3_1.HmyMethodsWeb3({
            web3,
            ensAddress: params.ensAddress,
            nodeURL: params.nodeURL,
        });
        await methods.init();
    }
    else {
        methods = new HmyMethods_1.HmyMethods({
            hmy,
            ensAddress: params.ensAddress,
            nodeURL: params.nodeURL,
        });
        await methods.init();
    }
    return {
        methods,
        addWallet: async (privateKey) => {
            if (params.sdk === "web3") {
                const ethUserAccount = await web3.eth.accounts.privateKeyToAccount(privateKey);
                web3.eth.accounts.wallet.add(ethUserAccount);
                web3.eth.defaultAccount = ethUserAccount.address;
                userAddress = ethUserAccount.address;
            }
            else {
                const account = await hmy.wallet.addByPrivateKey(privateKey);
                userAddress = account.address;
            }
        },
        getUserAddress: () => userAddress,
        setUseOneWallet: (value) => {
            if (params.sdk === "web3") {
                methods.setUseMetamask(value);
            }
            else {
                methods.setUseOneWallet(value);
            }
        },
        setUseMathWallet: (value) => {
            if (params.sdk === "web3") {
                methods.setUseMetamask(value);
            }
            else {
                methods.setUseOneWallet(value);
            }
        },
    };
};
